@@ -21,7 +21,7 @@
 #ifndef __EXEC_H__
 #define __EXEC_H__
 
-#include <glib/gmacros.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
